@@ -834,6 +834,14 @@ class Auth(object):
         })
         return SAP(**params)
 
+    def sendgrid(self):
+        """Connect to SendGrid."""
+        from bits.sendgrid import SendGrid
+        params = self.secrets.resolve({
+            "api_key": self.settings["sendgrid"]["api_key"],
+        })
+        return SendGrid(**params)
+
     def servicenow(self):
         """Connect to ServiceNow."""
         from bitsapiclient.services.servicenow import ServiceNow
